==> stylish-haskell-0.9.0.2-18-armv7h.pkg.tar.xz: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stylish-haskell
version: 0.9.0.2
id: stylish-haskell-0.9.0.2-fTW0IpGUw5FUIxZtcJMUn
key: stylish-haskell-0.9.0.2-fTW0IpGUw5FUIxZtcJMUn
license: BSD3
copyright: 2012 Jasper Van der Jeugt
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: https://github.com/jaspervdj/stylish-haskell
synopsis: Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:
    .
    <https://github.com/jaspervdj/stylish-haskell/blob/master/README.markdown>
category: Language
author: Jasper Van der Jeugt <m@jaspervdj.be>
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax
hidden-modules: Language.Haskell.Stylish.Align
                Language.Haskell.Stylish.Block Language.Haskell.Stylish.Config
                Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Parse
                Language.Haskell.Stylish.Step Language.Haskell.Stylish.Util
                Language.Haskell.Stylish.Verbose Paths_stylish_haskell
abi: 54a87acdb42e8e211560b9031b592da8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/stylish-haskell-0.9.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/stylish-haskell-0.9.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/stylish-haskell
hs-libraries: HSstylish-haskell-0.9.0.2-fTW0IpGUw5FUIxZtcJMUn
depends:
    aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF base-4.10.1.0
    bytestring-0.10.8.2 containers-0.5.10.2 directory-1.3.0.2
    filepath-1.4.1.2 file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG
    haskell-src-exts-1.20.2-AdPBe7NYupcAAtnLnTeHj2
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc syb-0.7-3Lq8MQxmYP07qktjI1jxu0
    yaml-0.8.28-7pVse71yk5N74lJEUwQaa2
abi-depends: aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF=117e2ccb320a02562b7dab8dac8cab03
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG=290747ebe676cf9f89313503a2e38e54
             haskell-src-exts-1.20.2-AdPBe7NYupcAAtnLnTeHj2=193ea0c6521f4bc4b9f85a58703b8207
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
             yaml-0.8.28-7pVse71yk5N74lJEUwQaa2=aeb24c22a0ae8fa727dabf763505365e
haddock-interfaces: /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html: /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stylish-haskell-0.9.0.2-20-armv7h.pkg.tar.xz: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stylish-haskell
version: 0.9.0.2
id: stylish-haskell-0.9.0.2-BjpmTZSJl9O695CaU6jpr2
key: stylish-haskell-0.9.0.2-BjpmTZSJl9O695CaU6jpr2
license: BSD3
copyright: 2012 Jasper Van der Jeugt
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: https://github.com/jaspervdj/stylish-haskell
synopsis: Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:
    .
    <https://github.com/jaspervdj/stylish-haskell/blob/master/README.markdown>
category: Language
author: Jasper Van der Jeugt <m@jaspervdj.be>
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax
hidden-modules: Language.Haskell.Stylish.Align
                Language.Haskell.Stylish.Block Language.Haskell.Stylish.Config
                Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Parse
                Language.Haskell.Stylish.Step Language.Haskell.Stylish.Util
                Language.Haskell.Stylish.Verbose Paths_stylish_haskell
abi: dfa902de5934589298a75a82148f29f1
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/stylish-haskell-0.9.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/stylish-haskell-0.9.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/stylish-haskell
hs-libraries: HSstylish-haskell-0.9.0.2-BjpmTZSJl9O695CaU6jpr2
depends:
    aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF base-4.10.1.0
    bytestring-0.10.8.2 containers-0.5.10.2 directory-1.3.0.2
    filepath-1.4.1.2 file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG
    haskell-src-exts-1.20.2-8f9nLOXfbxqI09lMyRO94h
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc syb-0.7-3Lq8MQxmYP07qktjI1jxu0
    yaml-0.8.29-Gi97Aw1KAGcEf1oVOFvTtA
abi-depends: aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF=117e2ccb320a02562b7dab8dac8cab03
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG=290747ebe676cf9f89313503a2e38e54
             haskell-src-exts-1.20.2-8f9nLOXfbxqI09lMyRO94h=0282f21593ff9b7fea5e6e00e89304c7
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
             yaml-0.8.29-Gi97Aw1KAGcEf1oVOFvTtA=1b9144eaf61cd2dfe095378b706474e8
haddock-interfaces: /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html: /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
